package example.cmp.select;

import javax.servlet.*;
import javax.servlet.http.*;

import javax.naming.*;
import javax.ejb.*;

import java.util.*;

import java.io.PrintWriter;

/**
 * A client to illustrate entity bean select methods.  Because select
 * methods aren't directly usable by clients, the beans need to
 * create business methods to return the selected values.
 */
public class ClientServlet extends HttpServlet {

  private StudentHome studentHome = null;
  private HouseHome houseHome = null;

  public void init()
    throws ServletException
  {
    try {
      // The JNDI context containing EJBs
      Context ejb = (Context) new InitialContext().lookup("java:comp/env/cmp");

      // get the house stub
      houseHome = (HouseHome)ejb.lookup("select_house");
      studentHome = (StudentHome)ejb.lookup("select_student");

    } catch (NamingException ne) {
      throw new ServletException(ne);
    }

  }

  public void service(HttpServletRequest req, HttpServletResponse res)
    throws java.io.IOException, ServletException
  {
    res.setContentType("text/html");

    PrintWriter out = res.getWriter();

    Iterator iterHouses = null;
    try {
      Collection houses = houseHome.findAll();
      iterHouses = houses.iterator();
    }
    catch (FinderException fe) {
      throw new ServletException(fe);
    }

    // iterate through all Houses
    while (iterHouses.hasNext()) {
      House house = (House)iterHouses.next();
      out.println("<H3>Boys living in " + house.getName() + ":</H3>");

      // Iterate through the sorted student names
      ListIterator boys = house.getAllBoyNamesSorted().listIterator();
      
      if (! boys.hasNext())
        out.println("No boys are living in " + house.getName());
      else {
        while (boys.hasNext())
          out.println(boys.next() + "<BR>");
      }

      out.println("<BR>");
    }
  }
}
