package example.cmp.single_table;

import javax.ejb.*;

/**
 * The client's view of a row in the house table.  It
 * defines methods for the managed fields and any business methods
 * exposed from the <code>HouseBean</code> implementation.
 *
 * <p>Clients always access the bean through the local interface.
 * They never use the bean implementation.  The separation between
 * interface and implementation lets Resin-CMP insert its transaction
 * and database caching code.
 *
 * <p>The home interface, HouseHome, is the main way to get instances
 * of the House interface.
 *
 * <p>All local interfaces extend <code>EJBLocalObject</code>.
 */
public interface House extends EJBLocalObject {
  /**
   * Returns the house name, which is the primary key of the bean.
   * The corresponding database column is <code>name</code>.
   *
   * <p>Local interfaces never define the <code>setXXX</code>
   * method for the primary key.
   *
   * <p>Local methods corresponding to container managed fields never
   * throw checked exceptions, although they may throw runtime
   * exceptions, like EJBException.
   *
   * @return the house's name
   *
   * @exception EJBException if the transaction or the database access
   * fails.  EJBException is a runtime exception.
   */
  String getName() throws EJBException;
  
  /**
   * Returns the number of points for the house.  The corresponding
   * database column is <code>points</code>.
   *
   * <p>The interface could also have exposed the
   * <code>getPoints</code> method.  This example keeps the setter
   * hidden to motivate the <code>addPoints</code> business method.
   *
   * @return the total points for the house
   *
   * @exception EJBException if the transaction or the database access
   * fails.
   */
  int getPoints() throws EJBException;
  /**
   * A business method to add points to the house.
   *
   * <p>Many updates will use business methods instead of setting the
   * methods directly.  By encapsulating the updates in business
   * methods, applications can ensure the integrity of the database.
   *
   * <p>For example, the addPoints business method might also check the
   * user's security and log any updates so a later audit can check
   * who added points to the house.
   *
   * @param delta the points to add or subtract from the house.
   */
  void addPoints(int delta);
}
